@@ -2,6 +2,7 @@ package resources
 
 import (
 	"fmt"
+	"time"
 
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/iam"
@@ -11,7 +12,7 @@ import (
 
 type IAMInstanceProfileRole struct {
 	svc     *iam.IAM
-	role    string
+	role    *iam.Role
 	profile *iam.InstanceProfile
 }
 
@@ -43,13 +44,13 @@ func ListIAMInstanceProfileRoles(sess *session.Session) ([]Resource, error) {
 
 				resources = append(resources, &IAMInstanceProfileRole{
 					svc:     svc,
-					role:    *outRole.RoleName,
+					role:    outRole,
 					profile: profile,
 				})
 			}
 		}
 
-		if *resp.IsTruncated == false {
+		if !*resp.IsTruncated {
 			break
 		}
 
@@ -63,7 +64,7 @@ func (e *IAMInstanceProfileRole) Remove() error {
 	_, err := e.svc.RemoveRoleFromInstanceProfile(
 		&iam.RemoveRoleFromInstanceProfileInput{
 			InstanceProfileName: e.profile.InstanceProfileName,
-			RoleName:            &e.role,
+			RoleName:            e.role.RoleName,
 		})
 	if err != nil {
 		return err
@@ -85,7 +86,13 @@ func (e *IAMInstanceProfileRole) Properties() types.Properties {
 
 	properties.
 		Set("InstanceProfile", e.profile.InstanceProfileName).
-		Set("InstanceRole", e.role)
+		Set("InstanceRole", e.role.RoleName).
+		Set("role:Path", e.role.Path).
+		Set("role:CreateDate", e.role.CreateDate.Format(time.RFC3339)).
+		Set("role:LastUsedDate", getLastUsedDate(e.role, time.RFC3339))
 
+	for _, tagValue := range e.role.Tags {
+		properties.SetTagWithPrefix("role", tagValue.Key, tagValue.Value)
+	}
 	return properties
 }
