@@ -3,11 +3,13 @@ package resources
 import (
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/iam"
+	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
 )
 
 type IAMOpenIDConnectProvider struct {
-	svc *iam.IAM
-	arn string
+	svc  *iam.IAM
+	arn  string
+	tags []*iam.Tag
 }
 
 func init() {
@@ -25,9 +27,20 @@ func ListIAMOpenIDConnectProvider(sess *session.Session) ([]Resource, error) {
 	}
 
 	for _, out := range resp.OpenIDConnectProviderList {
+
+		params := &iam.GetOpenIDConnectProviderInput{
+			OpenIDConnectProviderArn: out.Arn,
+		}
+		resp, err := svc.GetOpenIDConnectProvider(params)
+
+		if err != nil {
+			return nil, err
+		}
+
 		resources = append(resources, &IAMOpenIDConnectProvider{
-			svc: svc,
-			arn: *out.Arn,
+			svc:  svc,
+			arn:  *out.Arn,
+			tags: resp.Tags,
 		})
 	}
 
@@ -48,3 +61,14 @@ func (e *IAMOpenIDConnectProvider) Remove() error {
 func (e *IAMOpenIDConnectProvider) String() string {
 	return e.arn
 }
+
+func (e *IAMOpenIDConnectProvider) Properties() types.Properties {
+	properties := types.NewProperties()
+	properties.Set("Arn", e.arn)
+
+	for _, tag := range e.tags {
+		properties.SetTag(tag.Key, tag.Value)
+	}
+
+	return properties
+}
